==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/IOChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface IOChaosSpecFluent<A extends IOChaosSpecFluent<A>> extends Fluent<A>{
  public String getAction();
  public A withAction(String action);
  public Boolean hasAction();
  
  /**
   * This method has been deprecated, please use method buildAttr instead.
   * @return The buildable object.
   */
  @Deprecated
  public AttrOverrideSpec getAttr();
  public AttrOverrideSpec buildAttr();
  public A withAttr(AttrOverrideSpec attr);
  public Boolean hasAttr();
  public IOChaosSpecFluent.AttrNested<A> withNewAttr();
  public IOChaosSpecFluent.AttrNested<A> withNewAttrLike(AttrOverrideSpec item);
  public IOChaosSpecFluent.AttrNested<A> editAttr();
  public IOChaosSpecFluent.AttrNested<A> editOrNewAttr();
  public IOChaosSpecFluent.AttrNested<A> editOrNewAttrLike(AttrOverrideSpec item);
  public A addToContainerNames(Integer index,String item);
  public A setToContainerNames(Integer index,String item);
  public A addToContainerNames(java.lang.String... items);
  public A addAllToContainerNames(Collection<String> items);
  public A removeFromContainerNames(java.lang.String... items);
  public A removeAllFromContainerNames(Collection<String> items);
  public List<String> getContainerNames();
  public String getContainerName(Integer index);
  public String getFirstContainerName();
  public String getLastContainerName();
  public String getMatchingContainerName(Predicate<String> predicate);
  public Boolean hasMatchingContainerName(Predicate<String> predicate);
  public A withContainerNames(List<String> containerNames);
  public A withContainerNames(java.lang.String... containerNames);
  public Boolean hasContainerNames();
  public String getDelay();
  public A withDelay(String delay);
  public Boolean hasDelay();
  public String getDuration();
  public A withDuration(String duration);
  public Boolean hasDuration();
  public Integer getErrno();
  public A withErrno(Integer errno);
  public Boolean hasErrno();
  public A addToMethods(Integer index,String item);
  public A setToMethods(Integer index,String item);
  public A addToMethods(java.lang.String... items);
  public A addAllToMethods(Collection<String> items);
  public A removeFromMethods(java.lang.String... items);
  public A removeAllFromMethods(Collection<String> items);
  public List<String> getMethods();
  public String getMethod(Integer index);
  public String getFirstMethod();
  public String getLastMethod();
  public String getMatchingMethod(Predicate<String> predicate);
  public Boolean hasMatchingMethod(Predicate<String> predicate);
  public A withMethods(List<String> methods);
  public A withMethods(java.lang.String... methods);
  public Boolean hasMethods();
  
  /**
   * This method has been deprecated, please use method buildMistake instead.
   * @return The buildable object.
   */
  @Deprecated
  public MistakeSpec getMistake();
  public MistakeSpec buildMistake();
  public A withMistake(MistakeSpec mistake);
  public Boolean hasMistake();
  public A withNewMistake(String filling,Long maxLength,Long maxOccurrences);
  public IOChaosSpecFluent.MistakeNested<A> withNewMistake();
  public IOChaosSpecFluent.MistakeNested<A> withNewMistakeLike(MistakeSpec item);
  public IOChaosSpecFluent.MistakeNested<A> editMistake();
  public IOChaosSpecFluent.MistakeNested<A> editOrNewMistake();
  public IOChaosSpecFluent.MistakeNested<A> editOrNewMistakeLike(MistakeSpec item);
  public String getMode();
  public A withMode(String mode);
  public Boolean hasMode();
  public String getPath();
  public A withPath(String path);
  public Boolean hasPath();
  public Integer getPercent();
  public A withPercent(Integer percent);
  public Boolean hasPercent();
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSelectorSpec getSelector();
  public PodSelectorSpec buildSelector();
  public A withSelector(PodSelectorSpec selector);
  public Boolean hasSelector();
  public IOChaosSpecFluent.SelectorNested<A> withNewSelector();
  public IOChaosSpecFluent.SelectorNested<A> withNewSelectorLike(PodSelectorSpec item);
  public IOChaosSpecFluent.SelectorNested<A> editSelector();
  public IOChaosSpecFluent.SelectorNested<A> editOrNewSelector();
  public IOChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item);
  public String getValue();
  public A withValue(String value);
  public Boolean hasValue();
  public String getVolumePath();
  public A withVolumePath(String volumePath);
  public Boolean hasVolumePath();
  public interface AttrNested<N> extends Nested<N>,AttrOverrideSpecFluent<IOChaosSpecFluent.AttrNested<N>>{
    public N and();
    public N endAttr();
    
  }
  public interface MistakeNested<N> extends Nested<N>,MistakeSpecFluent<IOChaosSpecFluent.MistakeNested<N>>{
    public N and();
    public N endMistake();
    
  }
  public interface SelectorNested<N> extends Nested<N>,PodSelectorSpecFluent<IOChaosSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/IOChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface IOChaosSpecFluent<A extends IOChaosSpecFluent<A>> extends Fluent<A>{
  public String getAction();
  public A withAction(String action);
  public Boolean hasAction();
  
  /**
   * This method has been deprecated, please use method buildAttr instead.
   * @return The buildable object.
   */
  @Deprecated
  public AttrOverrideSpec getAttr();
  public AttrOverrideSpec buildAttr();
  public A withAttr(AttrOverrideSpec attr);
  public Boolean hasAttr();
  public IOChaosSpecFluent.AttrNested<A> withNewAttr();
  public IOChaosSpecFluent.AttrNested<A> withNewAttrLike(AttrOverrideSpec item);
  public IOChaosSpecFluent.AttrNested<A> editAttr();
  public IOChaosSpecFluent.AttrNested<A> editOrNewAttr();
  public IOChaosSpecFluent.AttrNested<A> editOrNewAttrLike(AttrOverrideSpec item);
  public A addToContainerNames(int index,String item);
  public A setToContainerNames(int index,String item);
  public A addToContainerNames(java.lang.String... items);
  public A addAllToContainerNames(Collection<String> items);
  public A removeFromContainerNames(java.lang.String... items);
  public A removeAllFromContainerNames(Collection<String> items);
  public List<String> getContainerNames();
  public String getContainerName(int index);
  public String getFirstContainerName();
  public String getLastContainerName();
  public String getMatchingContainerName(Predicate<String> predicate);
  public Boolean hasMatchingContainerName(Predicate<String> predicate);
  public A withContainerNames(List<String> containerNames);
  public A withContainerNames(java.lang.String... containerNames);
  public Boolean hasContainerNames();
  public String getDelay();
  public A withDelay(String delay);
  public Boolean hasDelay();
  public String getDuration();
  public A withDuration(String duration);
  public Boolean hasDuration();
  public Integer getErrno();
  public A withErrno(Integer errno);
  public Boolean hasErrno();
  public A addToMethods(int index,String item);
  public A setToMethods(int index,String item);
  public A addToMethods(java.lang.String... items);
  public A addAllToMethods(Collection<String> items);
  public A removeFromMethods(java.lang.String... items);
  public A removeAllFromMethods(Collection<String> items);
  public List<String> getMethods();
  public String getMethod(int index);
  public String getFirstMethod();
  public String getLastMethod();
  public String getMatchingMethod(Predicate<String> predicate);
  public Boolean hasMatchingMethod(Predicate<String> predicate);
  public A withMethods(List<String> methods);
  public A withMethods(java.lang.String... methods);
  public Boolean hasMethods();
  
  /**
   * This method has been deprecated, please use method buildMistake instead.
   * @return The buildable object.
   */
  @Deprecated
  public MistakeSpec getMistake();
  public MistakeSpec buildMistake();
  public A withMistake(MistakeSpec mistake);
  public Boolean hasMistake();
  public A withNewMistake(String filling,Long maxLength,Long maxOccurrences);
  public IOChaosSpecFluent.MistakeNested<A> withNewMistake();
  public IOChaosSpecFluent.MistakeNested<A> withNewMistakeLike(MistakeSpec item);
  public IOChaosSpecFluent.MistakeNested<A> editMistake();
  public IOChaosSpecFluent.MistakeNested<A> editOrNewMistake();
  public IOChaosSpecFluent.MistakeNested<A> editOrNewMistakeLike(MistakeSpec item);
  public String getMode();
  public A withMode(String mode);
  public Boolean hasMode();
  public String getPath();
  public A withPath(String path);
  public Boolean hasPath();
  public Integer getPercent();
  public A withPercent(Integer percent);
  public Boolean hasPercent();
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSelectorSpec getSelector();
  public PodSelectorSpec buildSelector();
  public A withSelector(PodSelectorSpec selector);
  public Boolean hasSelector();
  public IOChaosSpecFluent.SelectorNested<A> withNewSelector();
  public IOChaosSpecFluent.SelectorNested<A> withNewSelectorLike(PodSelectorSpec item);
  public IOChaosSpecFluent.SelectorNested<A> editSelector();
  public IOChaosSpecFluent.SelectorNested<A> editOrNewSelector();
  public IOChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item);
  public String getValue();
  public A withValue(String value);
  public Boolean hasValue();
  public String getVolumePath();
  public A withVolumePath(String volumePath);
  public Boolean hasVolumePath();
  public interface AttrNested<N> extends Nested<N>,AttrOverrideSpecFluent<IOChaosSpecFluent.AttrNested<N>>{
    public N and();
    public N endAttr();
    
  }
  public interface MistakeNested<N> extends Nested<N>,MistakeSpecFluent<IOChaosSpecFluent.MistakeNested<N>>{
    public N and();
    public N endMistake();
    
  }
  public interface SelectorNested<N> extends Nested<N>,PodSelectorSpecFluent<IOChaosSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}
